==> org.apache.sling.commons.testing-2.2.0-source-release.zip: org.apache.sling.commons.testing-2.2.0/src/main/java/org/apache/sling/commons/testing/jcr/MockPropertyIterator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.commons.testing.jcr;

import java.util.Iterator;

import javax.jcr.Property;
import javax.jcr.PropertyIterator;

public class MockPropertyIterator implements PropertyIterator {

    private final Iterator<Property> iterator;
    int index = 0;
    
    public MockPropertyIterator(Iterator <Property> it) {
        iterator = it;
    }
    
    public Property nextProperty() {
        return iterator.next();
    }

    public long getPosition() {
        return -1;
    }

    public long getSize() {
        return -1;
    }

    public void skip(long skipNum) {
    }

    public boolean hasNext() {
        return iterator.hasNext();
    }

    public Object next() {
        return nextProperty();
    }

    public void remove() {
        throw new Error("Not implemented: remove");
    }
}

==> org.apache.sling.commons.testing-2.2.2-source-release.zip: org.apache.sling.commons.testing-2.2.2/src/main/java/org/apache/sling/commons/testing/jcr/MockPropertyIterator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.commons.testing.jcr;

import javax.jcr.Property;
import javax.jcr.PropertyIterator;

import java.util.Iterator;

public class MockPropertyIterator implements PropertyIterator {

    private final Iterator<Property> iterator;
    int index = 0;

    public MockPropertyIterator(Iterator<Property> it) {
        iterator = it;
    }

    public Property nextProperty() {
        return iterator.next();
    }

    public long getPosition() {
        return -1;
    }

    public long getSize() {
        return -1;
    }

    public void skip(long skipNum) {}

    public boolean hasNext() {
        return iterator.hasNext();
    }

    public Object next() {
        return nextProperty();
    }

    public void remove() {
        throw new Error("Not implemented: remove");
    }
}
